@@ -12,7 +12,6 @@ from dagster import __version__ as dagster_version
 from dagster import seven
 from dagster.core.events import EngineEventData
 from dagster.core.instance import DagsterInstance
-from dagster.core.storage.pipeline_run import PipelineRunStatus
 from dagster.utils.error import serializable_error_info_from_exc_info
 
 from .util import (
@@ -40,15 +39,17 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
         self.pipeline_name = operator_parameters.pipeline_name
         self.pipeline_snapshot = operator_parameters.pipeline_snapshot
         self.execution_plan_snapshot = operator_parameters.execution_plan_snapshot
+        self.parent_pipeline_snapshot = operator_parameters.parent_pipeline_snapshot
         kwargs['name'] = 'dagster.{pipeline_name}.{task_id}'.format(
             pipeline_name=self.pipeline_name, task_id=operator_parameters.task_id
         ).replace(
             '_', '-'  # underscores are not permissible DNS names
         )
 
-        self.environment_dict = operator_parameters.environment_dict
+        self.run_config = operator_parameters.run_config
         self.mode = operator_parameters.mode
         self.step_keys = operator_parameters.step_keys
+        self.recon_repo = operator_parameters.recon_repo
         self._run_id = None
         # self.instance might be None in, for instance, a unit test setting where the operator
         # was being directly instantiated without passing through make_airflow_dag
@@ -94,7 +95,12 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
     @property
     def query(self):
         variables = construct_variables(
-            self.mode, self.environment_dict, self.pipeline_name, self.run_id, self.step_keys,
+            self.recon_repo,
+            self.mode,
+            self.run_config,
+            self.pipeline_name,
+            self.run_id,
+            self.step_keys,
         )
         variables = add_airflow_tags(variables, self.airflow_ts)
 
@@ -171,16 +177,19 @@ class DagsterKubernetesPodOperator(KubernetesPodOperator):
             launcher = pod_launcher.PodLauncher(kube_client=client, extract_xcom=self.xcom_push)
             try:
                 if self.instance:
-                    run = self.instance.get_or_create_run(
+                    run = self.instance.register_managed_run(
                         pipeline_name=self.pipeline_name,
                         run_id=self.run_id,
-                        environment_dict=self.environment_dict,
+                        run_config=self.run_config,
                         mode=self.mode,
+                        solids_to_execute=None,
                         step_keys_to_execute=None,
                         tags=None,
-                        status=PipelineRunStatus.MANAGED,
+                        root_run_id=None,
+                        parent_run_id=None,
                         pipeline_snapshot=self.pipeline_snapshot,
                         execution_plan_snapshot=self.execution_plan_snapshot,
+                        parent_pipeline_snapshot=self.parent_pipeline_snapshot,
                     )
 
                 # we won't use the "result", which is the pod's xcom json file
